@@ -7,3 +7,6 @@ from redis.asyncio.client import Redis
 _context_var: contextvars.ContextVar[Optional["Redis"]] = contextvars.ContextVar(
     "redis", default=None
 )
+_context_xx_pipe: contextvars.ContextVar[bool] = contextvars.ContextVar(
+    "redis_xx_pipe", default=False
+)
